import logging

class DFKLogger:
    def __init__ (self, logger: logging.Logger):
        self.logger = logger
        self.hadErrors = False
    
    def info(self, message):
        self.logger.info(message)
    
    def error(self, message):
        self.logger.error(message)
        self.hadErrors = True


from dfk_commons.classes.RPCProvider import RPCProvider

class Account:
    def __init__(self, account, rpcProvider: RPCProvider, account_data) -> None:
        self.account = account
        self.address = account.address
        self.key = account.key
        self.rpcProvider = rpcProvider
        if account_data != None:
            self.manager = account_data["pay_to"] if "pay_to" in account_data else None
            self.profession = account_data["profession"] if "profession" in account_data else "mining"
            self.enabled_quester = account_data["enabled_quester"] if "enabled_quester" in account_data else False
            self.enabled_manager = account_data["enabled_manager"] if "enabled_manager" in account_data else False
            self.questing = account_data["questing"] if "questing" in account_data else False
        else:
            self.manager = None
            self.profession = None
            self.enabled_quester = False
            self.enabled_manager = False
            self.questing = False
    
    @property
    def nonce(self):
        return self.rpcProvider.w3.eth.get_transaction_count(self.address, "pending")


class Order:
    def __init__(self, id, token, side, price, amount) -> None:
        self.orderId = id
        self.token = token
        self.side = side
        self.price = price
        self.amount = amount


import json
from pathlib import Path

current_file_path = Path(__file__).absolute()

ERC20Json_path = current_file_path.parent / "abi/ERC20.json"
ERC721Json_path = current_file_path.parent / "abi/ERC721.json"
HeroCoreJson_path = current_file_path.parent / "abi/HeroCoreDiamond.json"
HeroSaleJson_path = current_file_path.parent / "abi/HeroSale.json"
HeroBridgeJson_path = current_file_path.parent / "abi/HeroBridgeUpgradeable.json"
RouterJson_path = current_file_path.parent / "abi/UniswapV2Router02.json"
QuestCoreJson_path = current_file_path.parent / "abi/QuestCoreV3.json"
BazaarJson_path = current_file_path.parent / "abi/Bazaar.json"
PairJson_path = current_file_path.parent / "abi/UniswapPair.json"

ERC20Json = open(ERC20Json_path)
ERC20ABI = json.load(ERC20Json)

ERC721Json = open(ERC721Json_path)
ERC721ABI = json.load(ERC721Json)

HeroCoreJson = open(HeroCoreJson_path)
HeroCoreABI = json.load(HeroCoreJson)

HeroSaleJson = open(HeroSaleJson_path)
HeroSaleABI = json.load(HeroSaleJson)

HeroBridgeJson = open(HeroBridgeJson_path)
HeroBridgeABI = json.load(HeroBridgeJson)

RouterJson = open(RouterJson_path)
RouterABI = json.load(RouterJson)

QuestCoreJson = open(QuestCoreJson_path)
QuestCoreABI = json.load(QuestCoreJson)

BazaarJson = open(BazaarJson_path)
BazaarABI = json.load(BazaarJson)

PairJson = open(PairJson_path)
PairABI = json.load(PairJson)



import boto3
import json

def get_cypher_key(secret_name):
    session = boto3.session.Session()
    client = session.client(
        service_name='secretsmanager',
        region_name="us-east-1",
    )

    get_secret_value_response = client.get_secret_value(
            SecretId=secret_name
        )
   
    secret = get_secret_value_response['SecretString']
    return json.loads(secret)["dfk-secret-key"]
